@@ -43,7 +43,7 @@ use threadpool::ThreadPool;
 use std::sync::Arc;
 use std::sync::atomic::{AtomicBool, Ordering};
 
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct ThreadPoolExecutor {
     pool: ThreadPool,
     active: Arc<AtomicBool>,
@@ -75,6 +75,16 @@ impl ThreadPoolExecutor {
     }
 }
 
+/// Create a thread pool with one thread per CPU.
+/// On machines with hyperthreading,
+/// this will create one thread per hyperthread.
+#[cfg(feature = "defaults")]
+impl Default for ThreadPoolExecutor {
+    fn default() -> Self {
+        ThreadPoolExecutor::new(num_cpus::get())
+    }
+}
+
 impl Executor for ThreadPoolExecutor {
     fn execute<F>(&self, job: F)
     where
@@ -114,6 +124,19 @@ mod tests {
     use super::*;
     use std::time::Duration;
 
+    const LABEL: &'static str = "Threadpool";
+
+    #[test]
+    fn test_debug() {
+        let exec = ThreadPoolExecutor::new(2);
+        crate::tests::test_debug(&exec, LABEL);
+    }
+
+    #[test]
+    fn test_defaults() {
+        crate::tests::test_defaults::<ThreadPoolExecutor>(LABEL);
+    }
+
     #[test]
     fn run_with_two_threads() {
         let _ = env_logger::try_init();
@@ -181,4 +204,4 @@ mod tests {
         let res = latch.wait_timeout(Duration::from_secs(1));
         assert_eq!(res, 1);
     }
-}
\ No newline at end of file
+}
